#
# spec file for package apache2-mod_geoip
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define modname mod_geoip
Name:           apache2-mod_geoip
Version:        1.2.10
Release:        3.6
Summary:        Loop up IP addresses in GeoIP database
License:        Apache-1.1
Group:          Productivity/Networking/Web/Servers
Url:            http://www.maxmind.com/app/mod_geoip
Source:         https://github.com/maxmind/geoip-api-mod_geoip2/archive/%{version}.tar.gz#/geoip-api-mod_geoip2-%{version}.tar.gz
Patch0:         0001-use-AP_DECLARE_MODULE-if-possible-in-apache-2.4.patch
#
BuildRequires:  GeoIP-devel >= 1.4.3
BuildRequires:  apache2-devel
BuildRequires:  apache-rpm-macros
Requires:       %{apache_mmn}
Requires:       %{apache_suse_maintenance_mmn}
Requires:       apache2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
mod_geoip looks up the IP address of the client end user in MaxMind's GeoIP
country database.

%prep
%setup -q -n geoip-api-mod_geoip2-%{version}
%patch0 -p1

%build
%{apache_apxs} -c -lGeoIP mod_geoip.c

%install
mkdir -p %{buildroot}/%{apache_libexecdir}
cp -p .libs/mod_geoip.so %{buildroot}/%{apache_libexecdir}
mkdir -p %{buildroot}/%{apache_sysconfdir}/conf.d
cat <<-EOF > %{buildroot}/%{apache_sysconfdir}/conf.d/%{modname}.conf
<IfModule mod_geoip.c>
    GeoIPEnable On
    GeoIPEnableUTF8 On
    # GeoIPOutput [Notes|Env|All]
    GeoIPOutput All

    <IfModule prefork.c>
        GeoIPDBFile %{_localstatedir}/lib/GeoIP/GeoIP.dat
    </IfModule>
    <IfModule !prefork>
        GeoIPDBFile %{_localstatedir}/lib/GeoIP/GeoIP.dat MMapCache
    </IfModule>
</IfModule>
EOF

%check
set +x
%apache_test_module_load -m geoip -i %{modname}.conf
set -x

%files
%defattr(-,root,root)
%doc README.md README.php INSTALL.md Changes LICENSE
%{apache_libexecdir}/%{modname}.so
%config(noreplace) %{apache_sysconfdir}/conf.d/%{modname}.conf

%changelog
* Tue Sep 15 2015 jweberhofer@weberhofer.at
- Version 1.2.10
  * Update docs to note that GeoIP configuration directives cannot be placed in
    .htaccess files.
  * Fix small memleak (Boris Zentner)
  * A segfault when using multi-threaded workers was fixed. (Fix from thinker0.
    gh#maxmind/geoip-api-mod_geoip2#16.)
  * Several instances of manual memory management were switched to use the use
    Apache's memory pool. (Fix from thinker0.
    GitHub gh#maxmind/geoip-api-mod_geoip2#16.)
- Version 1.2.9
  * Added a new directive, GeoIPScanProxyHeaderField, to specify a custom
    header which contains the client's IP address (Sascha Kuehndel)
  * Added the ability to forward the result fields to a backend server/proxy
    via request header (Sascha Kuehndel)
- rebased patch
- reformatted spec
* Fri Sep  4 2015 pgajdos@suse.com
- test module with %%apache_module_test_load
* Thu Jul 16 2015 pgajdos@suse.com
- Requries: %%{apache_suse_maintenance_mmn}
  This will pull this module to the update (in released distribution)
  when apache maintainer thinks it is good (due api/abi changes).
* Fri Oct 31 2014 pgajdos@suse.com
- call spec-cleaner
- use apache rpm macros
* Tue Feb 11 2014 poeml@cmdline.net
- use a bzip2'ed tarball, to make debian building work again
* Wed Jul 31 2013 crrodriguez@opensuse.org
- 0001-use-AP_DECLARE_MODULE-if-possible-in-apache-2.4.patch
  use AP_DECLARE_MODULE in apache 2.4 so per-module logging control
  works.
* Wed Jul 31 2013 crrodriguez@opensuse.org
- Update to 1.2.8git in order to get upstream fixes
  for apache 2.4
* Mon Aug  6 2012 crrodriguez@opensuse.org
- Fix previous change.
* Mon Aug  6 2012 crrodriguez@opensuse.org
- Fix build with apache 2.4
* Fri Mar 23 2012 poeml@cmdline.net
- update to 1.2.7 (Aug 23th 2011)
  - Add support for GEOIP_NETSPEED_REV1
  - Experimental support for GEOIP_COUNTRY_EDITION_V6
  - Add GEOIP_DOMAIN_EDITION support
  changes from 1.2.6 (Sep 11th 2008):
  - GEOIP_METRO_CODE replace the depreciated GEOIP_DMA_CODE
* Mon Jun  6 2011 mrueckert@suse.de
- added mod_geoip-1.2.5_add_country_v6_db.patch
  add support vor the free ipv6 country db
* Fri Oct  2 2009 poeml@suse.de
- debianize the package, because only a very old mod_geoip is
  available on Debian (1.1.8), which doesn't return continent
  lookup data yet
* Fri Jul  3 2009 poeml@suse.de
- fix typo in last change (IfModules -> IfModule)
* Fri Jul  3 2009 poeml@suse.de
- enhance the example conf to load GeoIP database with the
  MMapCache option when using a threaded MPM, and set
  GeoIPEnableUTF8 On
* Mon Jun 22 2009 poeml@suse.de
- adjust path to GeoIP database in the packaged config file - the
  location was moved from /usr/share/GeoIP to /var/lib/GeoIP
* Thu Apr 23 2009 poeml@suse.de
- mark the config file "noreplace" in the RPM file list
* Fri Mar  6 2009 poeml@suse.de
- enable build on Fedora/CentOS
* Sun Nov 23 2008 poeml@suse.de
- update to 1.2.5. Lots of changes, compared to 1.1.8:
  1.2.5 Aug 13th 2008
    ! Fix GEOIP_REGION and GEOIP_COUNTRY_CODE when used with the GeoIPRegion database. Both are only set if a region or country was found. Previously a empty string was assigned to both ( Boris Zentner )
  - Add GEOIP_REGION_NAME for City and Region databases ( Boris Zentner )
  1.2.4 Jun 10th 2008
    ! mod_geoip2 has sets GEOIP_COUNTRY_CODE to -- for unknown countries when used with the country database. But for any other database ( City for example ) GEOIP_COUNTRY_CODE is unset for unknown countries. This is fixed now. Same for GEOIP_CONTINENT_CODE and GEOIP_COUNTRY_NAME. ( Boris Zentner )
  - Add GEOIP_ADDR. That's the address used to compute the geoip information. Exported as env, notes or both as usual ( Jason Caldwell )
  - Try to run always before mod_setenvif and mod_rewrite. ( Boris Zentner )
  1.2.3 Apr 26th 2008
  - Skip files that we can not open for some reason ( permission/typo ). Check and skip empty slots in geoip_header_parser ( Boris Zentner )
  - Slight performance increase - don't make per_dir ap_get_module_config call where we return DECLINED because cfg->GeoIPEnabled is true (Guenter Knauf)
  - NetWare/Win32 compilation fixes, since can't declare vars in middle of code (Guenter Knauf)
  1.2.2 Mar 18th 2008
  - Fix race condition for IO based caches like Standard. MMapCache and MemoryCache are not affected. ( Boris Zentner )
  1.2.1 Dec 17th 2007
    ! Notice, that all directives are _only_ valid in server context. Expect GeoIPEnabled. Check you configuraion with apachectl configtest ( Boris Zentner )
  - Added MMapCache option (Boris Zentner)
  - Change GeoIPEnabled from a serverwide option to a server/directory/location keyword. (Boris Zentner)
  - Fix a small memleak per child. Allocated in geoip_child_init free in geoip_cleanup (Boris Zentner)
  - GeoIP databases get used serverwide now. Not per child. See the README. (Boris Zentner)
  - Update README with more examples (Boris Zentner)
  - Added support for UTF8 output for GeoIP City databases (Boris Zentner)
  1.2.0 Aug 30th 2007
  - Fix segfault issue if GeoIP.dat file cannot be opened (Vladimir Sedlacek)
  - Added support for GEOIP_CONTINENT_CODE for GeoIP Country and City (Frank Mather)
  - Added GeoIPScanProxyHeaders directive to handle X-Forwarded-For headers (Frank Mather)
  - Updated documentation to specify that GeoIPFlags need to be passed
    as second parameter to GeoIPDBFile, instead of using the GeoIPFlags directive
* Sun Feb 11 2007 poeml@suse.de
- GeoIP has split off a -devel package, add it to BuildRequires
* Mon Dec 11 2006 poeml@suse.de
- add -lGeoIP
* Sun Dec 10 2006 poeml@suse.de
- initial package (1.1.8)
